/**
 * Merges two arrays, one of `ColDef` and one of `ColumnState`, and deduplicates them.
 * @remarks ColDef uses `field` and ColumnState uses `colId` to identify columns.
 * @privateRemarks For restoring saved `ColumnState` but also keep custom renderers and other `ColDef` properties.
 * @public
 */
export function mergeAndDedupColDefWithColumnState(colDefs, columnStates, arr1Field = 'field', arr2Field = 'colId') {
    const merged = {};
    const deduplicated = [];
    columnStates.forEach((state) => {
        const matchingColDef = colDefs.find((item) => item[arr1Field] === state[arr2Field]);
        if (matchingColDef) {
            const colDefStateMerge = Object.assign(Object.assign({}, matchingColDef), state);
            delete colDefStateMerge[arr2Field];
            merged[matchingColDef[arr1Field]] = colDefStateMerge;
            deduplicated.push(colDefStateMerge);
        }
    });
    colDefs.forEach((def) => {
        if (!merged.hasOwnProperty(def[arr1Field])) {
            const newObj = Object.assign({}, def);
            merged[def[arr1Field]] = newObj;
            deduplicated.push(newObj);
        }
    });
    return deduplicated;
}
